import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.cloud_assembly_schema._jsii
import aws_cdk.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-cdk/integ-tests", "1.157.0", __name__[0:-6], "integ-tests@1.157.0.jsii.tgz"
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
